@@ -17,7 +17,7 @@ type (
 
 const (
 	TransparentClose      = TransparentMode("close")
-	TransparentProxy      = TransparentMode("proxy")
+	TransparentProxy      = TransparentMode("proxy") // proxy all traffic
 	TransparentWhitelist  = TransparentMode("whitelist")
 	TransparentGfwlist    = TransparentMode("gfwlist")
 	TransparentFollowRule = TransparentMode("pac")
@@ -59,7 +59,7 @@ const (
 
 	AntipollutionDnsForward = Antipollution("dnsforward")
 	AntipollutionDoH        = Antipollution("doh")
-	AntipollutionAntiHijack = Antipollution("none")     // 历史原因，none代表“仅防止dns劫持”，不代表关闭
+	AntipollutionAntiHijack = Antipollution("none") // 历史原因，none代表“仅防止dns劫持”，不代表关闭
 	AntipollutionClosed     = Antipollution("closed")
 	AntipollutionAdvanced   = Antipollution("advanced") // 自定义
 
@@ -71,9 +71,12 @@ const (
 const (
 	RoutingATemplate = `default: proxy
 # write your own rules below
+domain(domain:mail.qq.com)->direct
+
 domain(geosite:geolocation-!cn)->proxy
 domain(geosite:google-scholar)->proxy
 domain(geosite:category-scholar-!cn, geosite:category-scholar-cn)->direct
 domain(geosite:cn)->direct
+ip(geoip:hk,geoip:mo)->proxy
 ip(geoip:private, geoip:cn)->direct`
 )
