@@ -17,7 +17,7 @@ func PatchSubscription(ctx *gin.Context) {
 	s := data.Subscription
 	index := s.ID - 1
 	if err != nil || s.TYPE != configure.SubscriptionType || index < 0 || index >= configure.GetLenSubscriptions() {
-		common.ResponseError(ctx, logError(nil, "bad request"))
+		common.ResponseError(ctx, logError("bad request"))
 		return
 	}
 	err = service.ModifySubscriptionRemark(s)
@@ -48,7 +48,7 @@ func PutSubscription(ctx *gin.Context) {
 	err := ctx.ShouldBindJSON(&data)
 	index := data.ID - 1
 	if err != nil || data.TYPE != configure.SubscriptionType || index < 0 || index >= configure.GetLenSubscriptions() {
-		common.ResponseError(ctx, logError(nil, "bad request: ID exceed range"))
+		common.ResponseError(ctx, logError("bad request: ID exceed range"))
 		return
 	}
 	err = service.UpdateSubscription(index, false)
