@@ -1,15 +1,16 @@
 package service
 
 import (
+	"fmt"
 	"github.com/v2rayA/v2rayA/common"
 	"github.com/v2rayA/v2rayA/db/configure"
-	"github.com/v2rayA/v2rayA/server/router/jwt"
+	"github.com/v2rayA/v2rayA/pkg/server/jwt"
 	"time"
 )
 
 func Login(username, password string) (token string, err error) {
 	if !IsValidAccount(username, password) {
-		return "", newError("wrong username or password")
+		return "", fmt.Errorf("wrong username or password")
 	}
 	dur := 3 * time.Hour
 	return jwt.MakeJWT(map[string]string{
@@ -27,7 +28,7 @@ func IsValidAccount(username, password string) bool {
 
 func Register(username, password string) (token string, err error) {
 	if configure.ExistsAccount(username) {
-		return "", newError("username exists")
+		return "", fmt.Errorf("username exists")
 	}
 	err = configure.SetAccount(username, common.CryptoPwd(password))
 	if err != nil {
@@ -40,6 +41,6 @@ func ValidPasswordLength(password string) (bool, error) {
 	if len(password) >= 6 && len(password) <= 32 {
 		return true, nil
 	} else {
-		return false, newError("length of password should be between 6 and 32")
+		return false, fmt.Errorf("length of password should be between 6 and 32")
 	}
 }
