@@ -5,26 +5,24 @@ import (
 	"github.com/v2rayA/v2rayA/core/ipforward"
 	"github.com/v2rayA/v2rayA/core/v2ray"
 	"github.com/v2rayA/v2rayA/core/v2ray/asset"
+	"github.com/v2rayA/v2rayA/core/v2ray/service"
 	"github.com/v2rayA/v2rayA/db/configure"
-	"log"
+	"github.com/v2rayA/v2rayA/pkg/util/log"
 )
 
 func StopV2ray() (err error) {
-	err = v2ray.StopV2rayService(true)
-	if err != nil {
-		return
-	}
-	return
+	v2ray.ProcessManager.Stop(true)
+	return nil
 }
 func StartV2ray() (err error) {
 	if css := configure.GetConnectedServers(); css.Len() == 0 {
-		return fmt.Errorf("failed: no server is connected. connect a server instead")
+		return fmt.Errorf("failed: no server is selected. please select at least one server")
 	}
 	return v2ray.UpdateV2RayConfig()
 }
 
 func IsClassicMode() bool {
-	supportLoadBalance := v2ray.CheckObservatorySupported() == nil
+	supportLoadBalance := service.CheckObservatorySupported() == nil
 	singleOutbound := len(configure.GetOutbounds()) <= 1
 	return singleOutbound && !supportLoadBalance
 }
@@ -45,9 +43,9 @@ func Disconnect(which configure.Which, clearOutbound bool) (err error) {
 		return
 	}
 	//update the v2ray config and restart v2ray
-	if v2ray.IsV2RayRunning() || IsClassicMode() {
+	if v2ray.ProcessManager.Running() || IsClassicMode() {
 		defer func() {
-			if err != nil && lastConnected != nil && v2ray.IsV2RayRunning() {
+			if err != nil && lastConnected != nil && v2ray.ProcessManager.Running() {
 				_ = configure.OverwriteConnects(lastConnected)
 				_ = v2ray.UpdateV2RayConfig()
 			}
@@ -63,15 +61,15 @@ func checkAssetsExist(setting *configure.Setting) error {
 	//FIXME: non-fully check
 	if setting.RulePortMode == configure.GfwlistMode || setting.Transparent == configure.TransparentGfwlist {
 		if !asset.LoyalsoldierSiteDatExists() {
-			return newError("GFWList file not exists. Try updating GFWList please")
+			return fmt.Errorf("GFWList file not exists. Try updating GFWList please")
 		}
 	}
 	return nil
 }
 
 func Connect(which *configure.Which) (err error) {
-	log.Println("Connect: begin")
-	defer log.Println("Connect: done")
+	log.Trace("Connect: begin")
+	defer log.Trace("Connect: done")
 	defer func() {
 		if err != nil {
 			err = fmt.Errorf("failed to connect: %w", err)
@@ -82,26 +80,26 @@ func Connect(which *configure.Which) (err error) {
 		return
 	}
 	if which == nil {
-		return newError("which can not be nil")
+		return fmt.Errorf("which can not be nil")
 	}
 	//configure the ip forward
 	if setting.IntranetSharing != ipforward.IsIpForwardOn() {
 		e := ipforward.WriteIpForward(setting.IntranetSharing)
 		if e != nil {
-			log.Println("[Warning]", e)
+			log.Warn("Connect: %v", e)
 		}
 	}
 	//locate server
 	currentConnected := configure.GetConnectedServersByOutbound(which.Outbound)
 	defer func() {
 		// if error occurs, restore the result of connecting
-		if err != nil && currentConnected != nil && v2ray.IsV2RayRunning() {
+		if err != nil && currentConnected != nil && v2ray.ProcessManager.Running() {
 			_ = configure.OverwriteConnects(currentConnected)
 			_ = v2ray.UpdateV2RayConfig()
 		}
 	}()
 	//save the result of connecting to database
-	supportLoadBalance := v2ray.CheckObservatorySupported() == nil
+	supportLoadBalance := service.CheckObservatorySupported() == nil
 	if !supportLoadBalance {
 		if err = configure.ClearConnects(which.Outbound); err != nil {
 			return
@@ -111,7 +109,7 @@ func Connect(which *configure.Which) (err error) {
 		return
 	}
 	//update the v2ray config and start/restart v2ray
-	if v2ray.IsV2RayRunning() || IsClassicMode() {
+	if v2ray.ProcessManager.Running() || IsClassicMode() {
 		if err = v2ray.UpdateV2RayConfig(); err != nil {
 			return
 		}
