@@ -1,28 +1,31 @@
 package service
 
 import (
+	"fmt"
+	url2 "net/url"
+	"strings"
+	"time"
+
 	"github.com/v2rayA/v2rayA/common"
 	"github.com/v2rayA/v2rayA/common/httpClient"
 	"github.com/v2rayA/v2rayA/common/resolv"
+	"github.com/v2rayA/v2rayA/core/serverObj"
 	"github.com/v2rayA/v2rayA/core/touch"
 	"github.com/v2rayA/v2rayA/core/v2ray"
 	"github.com/v2rayA/v2rayA/db/configure"
-	"github.com/v2rayA/v2rayA/infra/nodeData"
-	"strings"
-	"time"
 )
 
 func Import(url string, which *configure.Which) (err error) {
-	//log.Println(url)
+	//log.Trace(url)
 	resolv.CheckResolvConf()
 	url = strings.TrimSpace(url)
 	if lines := strings.Split(url, "\n"); len(lines) >= 2 {
 		infos, _, err := ResolveLines(url)
 		if err != nil {
-			return newError("failed to resolve addresses").Base(err)
+			return fmt.Errorf("failed to resolve addresses: %w", err)
 		}
 		for _, info := range infos {
-			err = configure.AppendServers([]*configure.ServerRaw{info.ToServerRaw()})
+			err = configure.AppendServers([]*configure.ServerRawV2{{ServerObj: info}})
 		}
 		return err
 	}
@@ -37,24 +40,24 @@ func Import(url string, which *configure.Which) (err error) {
 		strings.HasPrefix(url, "http-proxy://") ||
 		strings.HasPrefix(url, "https-proxy://") ||
 		strings.HasPrefix(url, "http2://") {
-		var n *nodeData.NodeData
-		n, err = ResolveURL(url)
+		var obj serverObj.ServerObj
+		obj, err = ResolveURL(url)
 		if err != nil {
 			return
 		}
 		if which != nil {
-			//修改
+			// the request is to modify a server
 			ind := which.ID - 1
 			if which.TYPE != configure.ServerType || ind < 0 || ind >= configure.GetLenServers() {
-				return newError("bad request")
+				return fmt.Errorf("bad request")
 			}
-			var sr *configure.ServerRaw
+			var sr *configure.ServerRawV2
 			sr, err = which.LocateServerRaw()
 			if err != nil {
 				return
 			}
-			sr.VmessInfo = n.VmessInfo
-			if err = configure.SetServer(ind, n.ToServerRaw()); err != nil {
+			sr.ServerObj = obj
+			if err = configure.SetServer(ind, &configure.ServerRawV2{ServerObj: obj}); err != nil {
 				return
 			}
 			css := configure.GetConnectedServers()
@@ -68,50 +71,56 @@ func Import(url string, which *configure.Which) (err error) {
 				}
 			}
 		} else {
-			//新建
-			//后端NodeData转前端TouchServerRaw压入TouchRaw.Servers
-			err = configure.AppendServers([]*configure.ServerRaw{n.ToServerRaw()})
+			// append a server
+			err = configure.AppendServers([]*configure.ServerRawV2{{ServerObj: obj}})
 		}
 	} else {
-		//不是ss://也不是vmess://，有可能是订阅地址
-		if strings.HasPrefix(url, "sub://") {
-			var e error
-			url, e = common.Base64StdDecode(url[6:])
-			if e != nil {
-				url, _ = common.Base64URLDecode(url[6:])
+		// subscription
+		source := url
+		if u, err := url2.Parse(source); err == nil {
+			if u.Scheme == "sub" {
+				var e error
+				source, e = common.Base64StdDecode(source[6:])
+				if e != nil {
+					source, _ = common.Base64URLDecode(source[6:])
+				}
+			} else if u.Scheme == "" {
+				u.Scheme = "http"
+				source = u.String()
 			}
-		}
-		if !strings.HasPrefix(url, "http://") && !strings.HasPrefix(url, "https://") {
-			url = "http://" + url
+		} else {
+			// maybe it is a OOCv1 token
 		}
 		c, err := httpClient.GetHttpClientAutomatically()
 		if err != nil {
 			return err
 		}
 		c.Timeout = 90 * time.Second
-		infos, status, err := ResolveSubscriptionWithClient(url, c)
+		infos, status, err := ResolveSubscriptionWithClient(source, c)
 		if err != nil {
-			return newError("failed to resolve subscription address").Base(err)
+			return fmt.Errorf("failed to resolve subscription address: %w", err)
 		}
-		//后端NodeData转前端TouchServerRaw压入TouchRaw.Subscriptions.Servers
-		servers := make([]configure.ServerRaw, len(infos))
+
+		// info to serverRawV2
+		servers := make([]configure.ServerRawV2, len(infos))
 		for i, v := range infos {
-			servers[i] = *v.ToServerRaw()
+			servers[i] = configure.ServerRawV2{ServerObj: v}
 		}
-		//去重
-		unique := make(map[configure.ServerRaw]interface{})
+
+		// deduplicate
+		unique := make(map[configure.ServerRawV2]interface{})
 		for _, s := range servers {
 			unique[s] = nil
 		}
-		uniqueServers := make([]configure.ServerRaw, 0)
+		uniqueServers := make([]configure.ServerRawV2, 0)
 		for _, s := range servers {
 			if _, ok := unique[s]; ok {
 				uniqueServers = append(uniqueServers, s)
 				delete(unique, s)
 			}
 		}
-		err = configure.AppendSubscriptions([]*configure.SubscriptionRaw{{
-			Address: url,
+		err = configure.AppendSubscriptions([]*configure.SubscriptionRawV2{{
+			Address: source,
 			Status:  string(touch.NewUpdateStatus()),
 			Servers: uniqueServers,
 			Info:    status,
