@@ -1,17 +1,17 @@
 package service
 
 import (
+	"errors"
 	"fmt"
 	"github.com/v2rayA/v2rayA/common/httpClient"
-	"github.com/v2rayA/v2rayA/common/netTools/netstat"
-	"github.com/v2rayA/v2rayA/common/netTools/ports"
 	"github.com/v2rayA/v2rayA/common/resolv"
+	"github.com/v2rayA/v2rayA/core/coreObj"
+	"github.com/v2rayA/v2rayA/core/serverObj"
 	"github.com/v2rayA/v2rayA/core/specialMode"
 	"github.com/v2rayA/v2rayA/core/v2ray"
-	"github.com/v2rayA/v2rayA/core/vmessInfo"
+	"github.com/v2rayA/v2rayA/core/v2ray/service"
 	"github.com/v2rayA/v2rayA/db/configure"
-	"github.com/v2rayA/v2rayA/plugin"
-	"log"
+	"github.com/v2rayA/v2rayA/pkg/util/log"
 	"net"
 	"net/http"
 	"strconv"
@@ -29,8 +29,8 @@ func Ping(which []*configure.Which, timeout time.Duration) (_ []*configure.Which
 	//暂时关闭透明代理
 	v2ray.CheckAndStopTransparentProxy()
 	defer func() {
-		if e := v2ray.CheckAndSetupTransparentProxy(true); e != nil {
-			err = newError(e).Base(err)
+		if e := v2ray.CheckAndSetupTransparentProxy(true, nil); e != nil {
+			err = fmt.Errorf("Ping: %v: %v", e, err)
 		}
 	}()
 	//多线程异步ping
@@ -54,15 +54,19 @@ func Ping(which []*configure.Which, timeout time.Duration) (_ []*configure.Which
 	return which, nil
 }
 
-func addHosts(tmpl *v2ray.Template, vms []vmessInfo.VmessInfo) {
-	tmpl.DNS = new(v2ray.DNS)
-	tmpl.DNS.Hosts = make(v2ray.Hosts)
+func addHosts(tmpl *v2ray.Template, vms []serverObj.ServerObj) {
+	if tmpl.DNS == nil {
+		tmpl.DNS = new(coreObj.DNS)
+	}
+	if tmpl.DNS.Hosts == nil {
+		tmpl.DNS.Hosts = make(coreObj.Hosts)
+	}
 	const concurrency = 5
 	var mu sync.Mutex
 	var limit = make(chan struct{}, concurrency)
 	var wg = sync.WaitGroup{}
 	for _, v := range vms {
-		if net.ParseIP(v.Add) == nil {
+		if net.ParseIP(v.GetHostname()) == nil {
 			wg.Add(1)
 			go func(addr string) {
 				limit <- struct{}{}
@@ -77,14 +81,14 @@ func addHosts(tmpl *v2ray.Template, vms []vmessInfo.VmessInfo) {
 				if len(ips) > 0 {
 					ips = v2ray.FilterIPs(ips)
 					mu.Lock()
-					if v2ray.CheckHostsListSupported() == nil {
+					if service.CheckHostsListSupported() == nil {
 						tmpl.DNS.Hosts[addr] = ips
 					} else {
 						tmpl.DNS.Hosts[addr] = ips[0]
 					}
 					mu.Unlock()
 				}
-			}(v.Add)
+			}(v.GetHostname())
 		}
 	}
 	wg.Wait()
@@ -92,6 +96,8 @@ func addHosts(tmpl *v2ray.Template, vms []vmessInfo.VmessInfo) {
 
 func TestHttpLatency(which []*configure.Which, timeout time.Duration, maxParallel int, showLog bool) ([]*configure.Which, error) {
 	specialMode.StopDNSSupervisor()
+	v2ray.CheckAndStopTransparentProxy()
+
 	var whiches = configure.NewWhiches(which)
 	for i := len(which) - 1; i >= 0; i-- {
 		if which[i].TYPE == configure.SubscriptionType { //去掉subscriptionType
@@ -99,9 +105,9 @@ func TestHttpLatency(which []*configure.Which, timeout time.Duration, maxParalle
 		}
 	}
 	which = whiches.Get()
-	v2rayRunning := v2ray.IsV2RayRunning()
+	v2rayRunning := v2ray.ProcessManager.Running()
 	wg := new(sync.WaitGroup)
-	vms := make([]vmessInfo.VmessInfo, len(which))
+	vms := make([]serverObj.ServerObj, len(which))
 	//init vmessInfos
 	for i := range which {
 		which[i].Latency = ""
@@ -110,57 +116,67 @@ func TestHttpLatency(which []*configure.Which, timeout time.Duration, maxParalle
 			which[i].Latency = err.Error()
 			continue
 		}
-		vms[i] = sr.VmessInfo
+		vms[i] = sr.ServerObj
 	}
 	//modify the template based on current configuration
-	var tmpl v2ray.Template
+	var (
+		tmpl *v2ray.Template
+		err  error
+	)
 	if v2rayRunning {
-		var err error
-		tmpl, err = v2ray.NewTemplateFromConfig()
+		tmpl, err = v2ray.NewTemplateFromConnectedServers(nil)
 		if err != nil {
-			return nil, err
+			if !errors.Is(err, v2ray.NoConnectedServerErr) {
+				log.Warn("NewTemplateFromConnectedServers: %v", err)
+			}
 		}
-	} else {
-		tmpl = v2ray.Template{}
+	}
+	if tmpl == nil {
+		tmpl = v2ray.NewEmptyTemplate(&configure.Setting{
+			RulePortMode:  configure.WhitelistMode,
+			TcpFastOpen:   configure.Default,
+			MuxOn:         configure.No,
+			Transparent:   configure.TransparentClose,
+			SpecialMode:   configure.SpecialModeNone,
+			AntiPollution: configure.AntipollutionClosed,
+		})
+		tmpl.SetAPI()
 	}
 	inboundPortMap := make([]string, len(vms))
 	pluginPortMap := make(map[int]int)
-	port := 0
-	nsmap, err := netstat.ToPortMap([]string{"tcp", "tcp6"})
-	if err != nil {
-		return nil, err
-	}
+	var toClose []net.Listener
 	for i, v := range vms {
 		if which[i].Latency != "" {
 			continue
 		}
 		//find a port for the inbound
-		if port == 0 {
-			port = 14321 //starting port
-		} else {
-			port = port + 1
-		}
+		var port int
 		for {
-			if !ports.IsOccupiedTCPPort(nsmap, port) {
+			l, err := net.Listen("tcp", "0.0.0.0:0")
+			if err == nil {
+				toClose = append(toClose, l)
+				port = l.Addr().(*net.TCPAddr).Port
 				break
 			}
-			port++
+			time.Sleep(100 * time.Millisecond)
 		}
 		v2rayInboundPort := strconv.Itoa(port)
 		pluginPort := 0
-		if plugin.HasProperPlugin(v) {
+		if v.NeedPlugin() {
 			// find a port for the plugin
-			port++
 			for {
-				if !ports.IsOccupiedTCPPort(nsmap, port) {
+				l, err := net.Listen("tcp", "127.0.0.1:0")
+				if err == nil {
+					toClose = append(toClose, l)
+					port = l.Addr().(*net.TCPAddr).Port
 					break
 				}
-				port++
+				time.Sleep(100 * time.Millisecond)
 			}
 			pluginPort = port
 			pluginPortMap[i] = port
 		}
-		err := tmpl.AddMappingOutbound(v, v2rayInboundPort, false, pluginPort, "socks")
+		err := tmpl.InsertMappingOutbound(v, v2rayInboundPort, false, pluginPort, "socks")
 		if err != nil {
 			if strings.Contains(err.Error(), "unsupported") {
 				which[i].Latency = "UNSUPPORTED PROTOCOL"
@@ -170,36 +186,14 @@ func TestHttpLatency(which []*configure.Which, timeout time.Duration, maxParalle
 		}
 		inboundPortMap[i] = v2rayInboundPort
 	}
-	//start plugins
-	//do not clean plugins to prevent current connections disconnecting
-	if len(pluginPortMap) > 0 {
-		for i, localPort := range pluginPortMap {
-			v := vms[i]
-			var plu plugin.Plugin
-			plu, err = plugin.NewPluginAndServe(localPort, v)
-			if err != nil {
-				return nil, err
-			}
-			plugin.GlobalPlugins.Add("outbound"+strconv.Itoa(localPort), plu)
-		}
+	for _, l := range toClose {
+		_ = l.Close()
 	}
+	time.Sleep(100 * time.Millisecond)
 	tmpl.Routing.DomainStrategy = "AsIs"
-	addHosts(&tmpl, vms)
+	addHosts(tmpl, vms)
 
-	err = v2ray.WriteV2rayConfig(tmpl.ToConfigBytes())
-	if err != nil {
-		return nil, err
-	}
-
-	if err = tmpl.CheckInboundPortsOccupied(); err != nil {
-		return nil, newError(err)
-	}
-
-	process, err := v2ray.RestartV2rayService(false)
-	if err != nil {
-		if process != nil {
-			_ = process.Kill()
-		}
+	if err := v2ray.ProcessManager.Start(tmpl); err != nil {
 		return nil, err
 	}
 	//limit the concurrency
@@ -208,7 +202,7 @@ func TestHttpLatency(which []*configure.Which, timeout time.Duration, maxParalle
 	for i := range which {
 		if which[i].Latency != "" {
 			if showLog {
-				fmt.Printf("Error[%v]%v: %v\n", i+1, which[i].Latency, which[i].Link)
+				log.Warn("Error[%v]%v: %v", i+1, which[i].Latency, which[i].Link)
 			}
 			continue
 		}
@@ -218,20 +212,18 @@ func TestHttpLatency(which []*configure.Which, timeout time.Duration, maxParalle
 			defer func() { <-cc; wg.Done() }()
 			httpLatency(which[i], inboundPortMap[i], timeout)
 			if showLog {
-				fmt.Printf("Test done[%v]%v: %v\n", i+1, which[i].Latency, which[i].Link)
+				log.Info("Test done[%v]%v: %v", i+1, which[i].Latency, which[i].Link)
 			}
 		}(i)
 	}
 	wg.Wait()
-	if process != nil {
-		_ = process.Kill()
-		v2ray.SetCoreProcess(nil)
-	}
 	if v2rayRunning && configure.GetConnectedServers() != nil {
-		err = v2ray.UpdateV2RayConfig()
+		err := v2ray.UpdateV2RayConfig()
 		if err != nil {
 			return which, fmt.Errorf("cannot restart v2ray-core: %w", err)
 		}
+	} else {
+		v2ray.ProcessManager.Stop(true)
 	}
 	if err := configure.NewWhiches(which).SaveLatencies(); err != nil {
 		return nil, fmt.Errorf("failed to save the latency test result: %v", err)
@@ -260,7 +252,6 @@ func httpLatency(which *configure.Which, port string, timeout time.Duration) {
 	req.Header.Set("User-Agent", "curl/7.70.0")
 	resp, err := c.Do(req)
 	if err != nil || resp.StatusCode < 200 || resp.StatusCode >= 400 {
-		s, _ := which.LocateServerRaw()
 		if err != nil {
 			es := strings.ToLower(err.Error())
 			switch {
@@ -273,10 +264,8 @@ func httpLatency(which *configure.Which, port string, timeout time.Duration) {
 			default:
 				which.Latency = err.Error()
 			}
-			log.Println(err, s.VmessInfo.Add+":"+s.VmessInfo.Port)
 		} else {
 			which.Latency = "BAD RESPONSE"
-			log.Println(resp.Status, s.VmessInfo.Add+":"+s.VmessInfo.Port)
 		}
 		return
 	}
